<?php
/**
 * Table Of Contents
 *
 * speaker_theme_setup ( sets up theme defaults and registers support for various WordPress features )
 * speaker_theme_content_width ( set the content width global variable )
 * speaker_theme_register_sidebars ( register sidebars )
 * speaker_theme_scripts ( enqueue scripts and styles )
 * speaker_theme_fonts_url ( returns the google fonts URL )
 * include other files
 */

if ( ! function_exists( 'speaker_theme_setup' ) ) {

	/**
	 * theme setup
	 *
	 * @since 1.0
	 */
	function speaker_theme_setup() {
		
		// text domain
		load_theme_textdomain( 'speaker-theme', get_template_directory() . '/languages' );

		// theme support
		add_theme_support( 'custom-logo', array(
			'width' => 220,
			'height' => 40,
			'flex-width' => true,
			'flex-height' => true,
			'header-text' => array( 'site-title', 'site-description' ),
		));
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );
		add_theme_support( 'custom-header', array(
			'default-image' => '',
			'width' => 1200,
			'height' => 200,
			'flex-height' => true,
			'flex-width' => true,
			'header-text' => false,
		));
		add_theme_support( 'custom-background', array(
			'default-color' => speaker_theme_get_default_bg_color(),
		));
		add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link', 'gallery', 'audio', 'status' ) );

		// editor style
		add_editor_style( array( 'css/editor-style.css', speaker_theme_fonts_url() ) );

		// register menus
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'speaker-theme' ),
			'top-bar' => esc_html__( 'Top Bar', 'speaker-theme' ),
			'footer' => esc_html__( 'Footer', 'speaker-theme' ),
			'mobile' => esc_html__( 'Mobile', 'speaker-theme' ),
		) );

		// declare woocommerce support
		add_theme_support( 'woocommerce' );

	}

} add_action( 'after_setup_theme', 'speaker_theme_setup' );

if ( ! function_exists( 'speaker_theme_content_width' ) ) {

	/**
	 * content width global
	 *
	 * @since 1.0
	 * @global int $content_width
	 */
	function speaker_theme_content_width() {
		
		$GLOBALS['content_width'] = apply_filters( 'speaker_theme_content_width', speaker_theme_get_container_width() );

	}

} add_action( 'after_setup_theme', 'speaker_theme_content_width', 0 );

if ( ! function_exists( 'speaker_theme_sidebars' ) ) {

	/**
	 * sidebars
	 *
	 * @since 1.0
	 */
	function speaker_theme_sidebars() {

		// sidebar
		register_sidebar( array(
			'name'          => esc_html__( 'Right Sidebar', 'speaker-theme' ),
			'id'            => 'sidebar-1',
			'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-main">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
		// sidebar
		register_sidebar( array(
			'name'          => esc_html__( 'Page Left Sidebar', 'speaker-theme' ),
			'id'            => 'sidebar-left',
			'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-main">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
		// sidebar
		register_sidebar( array(
			'name'          => esc_html__( 'Member Sidebar', 'speaker-theme' ),
			'id'            => 'sidebar-member',
			'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-main">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );

		// footer determine column size
		$footer_widget_column_width = speaker_theme_get_theme_mod( 'footer_widget_column_width', 4 );

		// footer
		register_sidebar( array(
			'name'          => esc_html__( 'Footer', 'speaker-theme' ),
			'id'            => 'sidebar-footer',
			'before_widget' => '<div id="%1$s" class="widget col col-' . esc_attr( $footer_widget_column_width ) . ' %2$s"><div class="widget-main">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );

		// header
		register_sidebar( array(
			'name'          => esc_html__( 'Masthead', 'speaker-theme' ),
			'id'            => 'sidebar-header',
			'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-main">',
			'after_widget'  => '</div></div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
		// banners
		register_sidebar( array(
		'name'          => __( 'Top Banner', 'speaker-theme' ),
		'id'            => 'top-banner',
		'description'   => __( 'Add widgets here to appear in your top banner area.', 'speaker-theme' ),
		'before_widget' => '<div id="top-banner" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="top-banner-widget-title">',
		'after_title'   => '</h4>',
		) );

		register_sidebar( array(
		'name'          => __( 'Bottom Banner', 'speaker-theme' ),
		'id'            => 'bottom-banner',
		'description'   => __( 'Add widgets here to appear in your bottom banner area.', 'speaker-theme' ),
		'before_widget' => '<div id="bottom-banner" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="bottom-banner-widget-title">',
		'after_title'   => '</h4>',
		) );
		// landing page
		register_sidebar(array(
		'name'          => __( 'Landing Page Footer', 'speaker-theme' ),
		'id'   => 'landing-footer',
		'description'   => 'Add Footer widgets to Landing Page.',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'   => '</h4>'
	));

	}

} add_action( 'widgets_init', 'speaker_theme_sidebars' );

/**
 * Register Hooks and banner widgets
 */
add_action( 'speaker_theme_after_header', 'add_top_banner' );
function add_top_banner()
{ ?>
<?php dynamic_sidebar('top-banner'); ?>
<?php } add_action( 'speaker_theme_before_footer', 'add_bottom_banner' ); function add_bottom_banner() 
{ ?>
<?php dynamic_sidebar('bottom-banner'); ?>
<?php }

if ( ! function_exists( 'speaker_theme_scripts' ) ) {
	
	/**
	 * scripts and styles
	 *
	 * @since 1.0
	 */
	function speaker_theme_scripts() {

		// theme
		$theme = wp_get_theme();

		// socrates plugin options
		$plugin_options = get_option( 'soc_custom_codes' );

		// css
		wp_enqueue_style( 'speaker-theme-style', get_stylesheet_uri(), array(), $theme->get( 'Version' ) );
		if ( is_array( $plugin_options ) && isset( $plugin_options['soc_function_disable_font_awesome'] ) && $plugin_options['soc_function_disable_font_awesome'] == 'on' ) {
			// do not load the font awesome files
		} else {
			wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/fonts/font-awesome/font-awesome-min.css' );
		}
		wp_enqueue_style( 'speaker-theme-google-fonts', speaker_theme_fonts_url(), array(), $theme->get( 'Version' ) );
		 if ( is_page_template( 'template-landing.php' ) ) {
		wp_enqueue_style( 'speaker-theme-landing', get_stylesheet_directory_uri() . '/landing.css' );
		 }

		// js
		wp_enqueue_script( 'speaker-theme-main-js', get_template_directory_uri() . '/js/general.js', array( 'jquery' ), $theme->get( 'Version' ), true );
		if ( is_page_template( 'template-masonry.php' ) || is_page_template( 'template-masonry-sidebar.php' ) ) {
			wp_enqueue_script( 'speaker-theme-plugins-js', get_template_directory_uri() . '/js/masonry.js', array( 'jquery' ), $theme->get( 'Version' ), true );
		}

		// comment reply
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

	}

} add_action( 'wp_enqueue_scripts', 'speaker_theme_scripts' );

if ( ! function_exists( 'speaker_theme_fonts_url' ) ) {

	/**
	 * returns the google fonts URL
	 *
	 * @since 1.0
	 */
	function speaker_theme_fonts_url() {
		
		$font_url = '';

		// all fonts
		$google_fonts = speaker_theme_get_fonts();
		$google_fonts = $google_fonts['google'];

		// user set fonts
		$primary_font = esc_html( speaker_theme_get_theme_mod( 'primary_font', 'Poppins' ) );
		$secondary_font = esc_html( speaker_theme_get_theme_mod( 'secondary_font', 'Montserrat' ) );

		// is primary font from google?
		$primary_font_google = false;
		if ( in_array( $primary_font, $google_fonts ) ) {
			$primary_font_google = true;
		}

		// is secondary font from google?
		$secondary_font_google = false;
		if ( in_array( $secondary_font, $google_fonts ) ) {
			$secondary_font_google = true;
		}

		/*
		Translators: If there are characters in your language that are not supported
		by chosen font(s), translate this to 'off'. Do not translate into your own language.
		*/
		$font_state = _x( 'on', 'Google fonts: on or off', 'speaker-theme' );
		if ( 'off' !== $font_state && ( $primary_font_google || $secondary_font_google ) ) {
					
			// first part of URL
			$url = '';			
			if ( $primary_font_google && $secondary_font_google ) {
				$url = $primary_font . ':300,400,500,700|' . $secondary_font . ':300,400,500,700';
			} elseif ( $primary_font_google ) {
				$url = $primary_font . ':300,400,500,700';
			} elseif ( $secondary_font_google ) {
				$url = $secondary_font . ':300,400,500,700';
			}

			// the full URL
			$font_url = add_query_arg( 'family', urlencode(  $url . '&subset=latin,latin-ext' ), "//fonts.googleapis.com/css" );

		}

		return $font_url;
	}

}

// options
include get_template_directory() . '/inc/post-options.php';
include get_template_directory() . '/inc/term-options.php';
include get_template_directory() . '/inc/theme-options.php';

// functions
include get_template_directory() . '/inc/logic.php';
include get_template_directory() . '/inc/display.php';

// widgets
include get_template_directory() . '/inc/widgets/widget.social.php';
include get_template_directory() . '/inc/widgets/widget.instagram.php';
include get_template_directory() . '/inc/widgets/widget.posts.php';

/**
 * WooCommerce Unhook sidebar
 */
if ( speaker_theme_get_theme_mod( 'remove_woocommerce_sidebar', 1 ) == 1 ) {
	remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10);
}

add_filter( 'body_class','landing_body_class' );
function landing_body_class( $classes ) {
 
    if ( is_page_template( 'template-landing.php' ) ) {
        $classes[] = 'body-general-layout-wrapped';
    }
    return $classes;

}
// Shortcodes in Widgets
add_filter('widget_text', 'do_shortcode');

require_once('wp-updates-theme.php');
new WPUpdatesThemeUpdater_2284( 'http://wp-updates.com/api/2/theme', basename( get_template_directory() ) );