<?php
/**
 * Table of Contents
 *
 * speaker_theme_post_options_scripts ( Enqueue admin scripts and styles )
 * speaker_theme_register_meta_boxes ( Register meta boxes )
 * speaker_theme_custom_header_meta_box_callback ( Custom Header - Display callback )
 * speaker_theme_post_elements_meta_box_callback ( Post Elements - Display callback )
 * speaker_theme_custom_nav_menu_meta_box_callback ( Custom nav menu - Display callback )
 * speaker_theme_custom_header_meta_box_save ( Custom Header - Save )
 * speaker_theme_post_elements_meta_box_save ( Post Elements - Save )
 * speaker_theme_custom_nav_menu_meta_box_save ( Custom nav menu - Save )
 */

/**
 * Enqueue admin scripts and styles
 *
 * @since 1.0
 */
function speaker_theme_post_options_scripts( $hook ) {

	// if not on edit page do not proced
	if ( 'post-new.php' != $hook && 'post.php' != $hook ) {
		return;
	}

	// the media library
	wp_enqueue_media();

	// custom scripts
	wp_register_script( 'speaker-theme-post-options-scripts', get_template_directory_uri() . '/js/post-options.js', array( 'jquery' ) );
	wp_localize_script( 'speaker-theme-post-options-scripts', 'meta_image',
		array(
			'title' => __( 'Set custom header image', 'speaker-theme' ),
			'button' => __( 'Use this image', 'speaker-theme' ),
		)
	);
	wp_enqueue_script( 'speaker-theme-post-options-scripts' );

	// custom CSS
	wp_enqueue_style( 'speaker-theme-post-options-style', get_template_directory_uri() . '/css/post-options.css' );

} add_action( 'admin_enqueue_scripts', 'speaker_theme_post_options_scripts' );

/**
 * Register meta boxes
 *
 * @since 1.0
 */
function speaker_theme_register_meta_boxes() {

	// custom header
	add_meta_box( 'speaker-theme-custom-header-meta-box', esc_html__( 'Custom Masthead / Header', 'speaker-theme' ), 'speaker_theme_custom_header_meta_box_callback', array( 'post', 'page' ), 'side', 'low' );

	// elements
	add_meta_box( 'speaker-theme-post-elements-meta-box', esc_html__( 'Elements', 'speaker-theme' ), 'speaker_theme_post_elements_meta_box_callback', array( 'post', 'page' ), 'side', 'low' );

	// custom menu
	add_meta_box( 'speaker-theme-custom-nav-menu-meta-box', esc_html__( 'Header Navigation', 'speaker-theme' ), 'speaker_theme_custom_nav_menu_meta_box_callback', array( 'post', 'page' ), 'side', 'low' );

} add_action( 'add_meta_boxes', 'speaker_theme_register_meta_boxes' );
 
/**
 * Custom Header - Display callback
 *
 * @since 1.0
 */
function speaker_theme_custom_header_meta_box_callback( $post ) {

	// nonces for security
	wp_nonce_field( 'speaker_theme_custom_header_image', 'speaker_theme_custom_header_image_nonce' );

	// current value
	$value = get_post_meta( $post->ID, '_speaker_theme_custom_header_image', true );

	// display options
	?>
	<div class="speaker-theme-post-options-upload <?php if ( $value ) echo 'speaker-theme-post-options-upload-active'; ?>">
		
		<div class="speaker-theme-post-options-upload-thumbnail">
			<?php 
				if ( $value ) {
					$image = wp_get_attachment_image_src( $value, 'medium' );
					echo '<img style="max-width: 100%;" src="' . $image[0] . '" />';					
				} 
			?>
		</div><!-- .speaker-theme-post-options-upload-thumbnail -->

		<p class="speaker-theme-post-options-upload-note"><?php esc_html_e( 'Click the image to edit or update', 'speaker-theme' ); ?></p>

		<a href="#" class="speaker-theme-post-options-upload-button"><?php esc_html_e( 'Set custom header image', 'speaker-theme' ); ?></a>
		<a href="#" class="speaker-theme-post-options-upload-clear"><?php esc_html_e( 'Remove custom header image', 'speaker-theme' ); ?></a>

		<input type="hidden" class="speaker-theme-post-options-upload-id" id="speaker_theme_custom_header_image" name="_speaker_theme_custom_header_image" value="<?php echo esc_attr( $value ); ?>" />

	</div><!-- .speaker-theme-post-options-upload -->

	<?php
		// current value
		$value = get_post_meta( $post->ID, '_speaker_theme_header_height', true );
	?>

	<div class="speaker-theme-post-options-text" style="border-top:1px solid #eee; margin-top: 15px; padding-top: 15px;">
		<label for="speaker_theme_header_height"><?php esc_html_e( 'Masthead / Header Min Height', 'speaker-theme' ); ?></label><br>
		<small><?php esc_html_e( 'Accepts any value that the CSS height rule accepts ( 200px, 50vh... )', 'speaker-theme' ); ?></small><br>
		<input type="text" name="_speaker_theme_header_height" id="speaker_theme_header_height" value="<?php echo esc_attr( $value ); ?>" />
	</div><!-- .speaker-theme-post-options-text -->
	<?php

}

/**
 * Post Elements - Display callback
 *
 * @since 1.0
 */
function speaker_theme_post_elements_meta_box_callback( $post ) {

	// nonces for security
	wp_nonce_field( 'speaker_theme_hide_post_title', 'speaker_theme_hide_post_title_nonce' );

	// current value
	$value_featured_image = get_post_meta( $post->ID, '_speaker_theme_hide_featured_image', true );
	$value_top_bar = get_post_meta( $post->ID, '_speaker_theme_hide_top_bar', true );
	$value_header = get_post_meta( $post->ID, '_speaker_theme_hide_header', true );
	$value_primary_nav = get_post_meta( $post->ID, '_speaker_theme_hide_primary_nav', true );
	$value = get_post_meta( $post->ID, '_speaker_theme_hide_post_title', true );
	$value_footer_widgets = get_post_meta( $post->ID, '_speaker_theme_hide_footer_widgets', true );
	$value_footer_bottom = get_post_meta( $post->ID, '_speaker_theme_hide_footer_bottom', true );

	// display options
	?>
	<div class="speaker-theme-post-options-checkbox">

		<!-- Hide Featured Image -->
		<input type="checkbox" class="speaker-theme-post-options-upload-id" id="speaker_theme_hide_featured_image" name="_speaker_theme_hide_featured_image" value="hide" <?php if ( $value_featured_image == 'hide' ) echo 'checked'; ?> />
		<label for="speaker_theme_hide_featured_image"><?php esc_html_e( 'Hide Featured Image', 'speaker-theme' ); ?></label>
	
	</div><!-- .speaker-theme-post-options-checkbox -->

	<div class="speaker-theme-post-options-checkbox">

		<!-- Hide Top Bar -->
		<input type="checkbox" class="speaker-theme-post-options-upload-id" id="speaker_theme_hide_top_bar" name="_speaker_theme_hide_top_bar" value="hide" <?php if ( $value_top_bar == 'hide' ) echo 'checked'; ?> />
		<label for="speaker_theme_hide_top_bar"><?php esc_html_e( 'Hide Top Bar', 'speaker-theme' ); ?></label>
	
	</div><!-- .speaker-theme-post-options-checkbox -->

	<div class="speaker-theme-post-options-checkbox">

		<!-- Hide Header -->
		<input type="checkbox" class="speaker-theme-post-options-upload-id" id="speaker_theme_hide_header" name="_speaker_theme_hide_header" value="hide" <?php if ( $value_header == 'hide' ) echo 'checked'; ?> />
		<label for="speaker_theme_hide_header"><?php esc_html_e( 'Hide Header', 'speaker-theme' ); ?></label>

	</div><!-- .speaker-theme-post-options-checkbox -->

	<div class="speaker-theme-post-options-checkbox">

		<!-- Hide Primary Nav -->
		<input type="checkbox" class="speaker-theme-post-options-upload-id" id="speaker_theme_hide_primary_nav" name="_speaker_theme_hide_primary_nav" value="hide" <?php if ( $value_primary_nav == 'hide' ) echo 'checked'; ?> />
		<label for="speaker_theme_hide_primary_nav"><?php esc_html_e( 'Hide Primary Nav', 'speaker-theme' ); ?></label>

	</div><!-- .speaker-theme-post-options-checkbox -->

	<div class="speaker-theme-post-options-checkbox">

		<!-- Hide Title -->
		<input type="checkbox" class="speaker-theme-post-options-upload-id" id="speaker_theme_hide_post_title" name="_speaker_theme_hide_post_title" value="hide" <?php if ( $value == 'hide' ) echo 'checked'; ?> />
		<label for="speaker_theme_hide_post_title"><?php esc_html_e( 'Hide Title', 'speaker-theme' ); ?></label>

	</div><!-- .speaker-theme-post-options-checkbox -->

	<div class="speaker-theme-post-options-checkbox">

		<!-- Hide Footer Widgets -->
		<input type="checkbox" class="speaker-theme-post-options-upload-id" id="speaker_theme_hide_footer_widgets" name="_speaker_theme_hide_footer_widgets" value="hide" <?php if ( $value_footer_widgets == 'hide' ) echo 'checked'; ?> />
		<label for="speaker_theme_hide_footer_widgets"><?php esc_html_e( 'Hide Footer Widgets', 'speaker-theme' ); ?></label>

	</div><!-- .speaker-theme-post-options-checkbox -->

	<div class="speaker-theme-post-options-checkbox">

		<!-- Hide Footer Bottom -->
		<input type="checkbox" class="speaker-theme-post-options-upload-id" id="speaker_theme_hide_footer_bottom" name="_speaker_theme_hide_footer_bottom" value="hide" <?php if ( $value_footer_bottom == 'hide' ) echo 'checked'; ?> />
		<label for="speaker_theme_hide_footer_bottom"><?php esc_html_e( 'Hide Footer Bottom', 'speaker-theme' ); ?></label>

	</div><!-- .speaker-theme-post-options-checkbox -->
	<?php

}

/**
 * Nav menu - Display callback
 *
 * @since 1.0
 */
function speaker_theme_custom_nav_menu_meta_box_callback( $post ) {

	// nonces for security
	wp_nonce_field( 'speaker_theme_custom_nav_menu', 'speaker_theme_custom_nav_menu_nonce' );

	// current value
	$value = get_post_meta( $post->ID, '_speaker_theme_custom_nav_menu', true );

	// display options
	?>
	<div class="speaker-theme-post-options-select">

		<?php
			$menus = get_terms( 'nav_menu', array( 'hide_empty' => false ) );
		?>
		<select name="_speaker_theme_custom_nav_menu">
			<option value="default"><?php esc_html_e( 'Default', 'speaker-theme' ); ?></option>
			<?php if ( ! is_wp_error( $menus ) ) : ?>
				<?php foreach ( $menus as $menu ) : ?>
					<option value="<?php echo $menu->term_id; ?>" <?php selected( $value, $menu->term_id ); ?>><?php echo $menu->name; ?></option>
				<?php endforeach; ?>
			<?php endif; ?>
		</select>
	
	</div><!-- .speaker-theme-post-options-checkbox -->
	<?php

}

/**
 * Custom Header - Save
 *
 * @since 1.0
 */
function speaker_theme_custom_header_meta_box_save( $post_id ) {

	// do not proceed if nonce not set
	if ( ! isset( $_POST['speaker_theme_custom_header_image_nonce'] ) ) {
		return $post_id;
	}

	// get nonce value
	$nonce = $_POST['speaker_theme_custom_header_image_nonce'];

	// do not proceed if nonce is wrong
	if ( ! wp_verify_nonce( $nonce, 'speaker_theme_custom_header_image' ) ) {
		return $post_id;
	}

	// do not proceed if autosave
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return $post_id;
	}

	// do not proceed if user does not have permission
	if ( 'page' == $_POST['post_type'] ) {
		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return $post_id;
		}
	} else {
		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return $post_id;
		}
	}

	// sanitize input
	$value = sanitize_text_field( $_POST['_speaker_theme_custom_header_image'] );

	// update meta
	update_post_meta( $post_id, '_speaker_theme_custom_header_image', $value );

	// sanitize input
	$value = sanitize_text_field( $_POST['_speaker_theme_header_height'] );

	// update meta
	update_post_meta( $post_id, '_speaker_theme_header_height', $value );

} add_action( 'save_post', 'speaker_theme_custom_header_meta_box_save' );

/**
 * Elements - Save
 *
 * @since 1.0
 */
function speaker_theme_post_elements_meta_box_save( $post_id ) {

	// do not proceed if nonce not set
	if ( ! isset( $_POST['speaker_theme_hide_post_title_nonce'] ) ) {
		return $post_id;
	}

	// get nonce value
	$nonce = $_POST['speaker_theme_hide_post_title_nonce'];

	// do not proceed if nonce is wrong
	if ( ! wp_verify_nonce( $nonce, 'speaker_theme_hide_post_title' ) ) {
		return $post_id;
	}

	// do not proceed if autosave
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return $post_id;
	}

	// do not proceed if user does not have permission
	if ( 'page' == $_POST['post_type'] ) {
		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return $post_id;
		}
	} else {
		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return $post_id;
		}
	}

	/**
	 * Get values
	 */

	// featured images
	$value_featured_image = '';
	if ( isset( $_POST['_speaker_theme_hide_featured_image'] ) ) {
		$value_featured_image = sanitize_text_field( $_POST['_speaker_theme_hide_featured_image'] );	
	}

	// top bar
	$value_top_bar = '';
	if ( isset( $_POST['_speaker_theme_hide_top_bar'] ) ) {
		$value_top_bar = sanitize_text_field( $_POST['_speaker_theme_hide_top_bar'] );	
	}

	// header
	$value_header = '';
	if ( isset( $_POST['_speaker_theme_hide_header'] ) ) {
		$value_header = sanitize_text_field( $_POST['_speaker_theme_hide_header'] );	
	}

	// primary navigation
	$value_primary_nav = '';
	if ( isset( $_POST['_speaker_theme_hide_primary_nav'] ) ) {
		$value_primary_nav = sanitize_text_field( $_POST['_speaker_theme_hide_primary_nav'] );	
	}

	// post title
	$value = '';
	if ( isset( $_POST['_speaker_theme_hide_post_title'] ) ) {
		$value = sanitize_text_field( $_POST['_speaker_theme_hide_post_title'] );	
	}

	// footer widgets
	$value_footer_widgets = '';
	if ( isset( $_POST['_speaker_theme_hide_footer_widgets'] ) ) {
		$value_footer_widgets = sanitize_text_field( $_POST['_speaker_theme_hide_footer_widgets'] );	
	}

	// footer bottom
	$value_footer_bottom = '';
	if ( isset( $_POST['_speaker_theme_hide_footer_bottom'] ) ) {
		$value_footer_bottom = sanitize_text_field( $_POST['_speaker_theme_hide_footer_bottom'] );	
	}

	/**
	 * Update
	 */

	// featured image
	if ( $value_featured_image == '' ) {
		delete_post_meta( $post_id, '_speaker_theme_hide_featured_image' );
	} else {
		update_post_meta( $post_id, '_speaker_theme_hide_featured_image', $value_featured_image );
	}

	// top bar
	if ( $value_top_bar == '' ) {
		delete_post_meta( $post_id, '_speaker_theme_hide_top_bar' );
	} else {
		update_post_meta( $post_id, '_speaker_theme_hide_top_bar', $value_top_bar );
	}

	// header
	if ( $value_header == '' ) {
		delete_post_meta( $post_id, '_speaker_theme_hide_header' );
	} else {
		update_post_meta( $post_id, '_speaker_theme_hide_header', $value_header );
	}

	// primary nav
	if ( $value_primary_nav == '' ) {
		delete_post_meta( $post_id, '_speaker_theme_hide_primary_nav' );
	} else {
		update_post_meta( $post_id, '_speaker_theme_hide_primary_nav', $value_primary_nav );
	}

	// post title
	if ( $value == '' ) {
		delete_post_meta( $post_id, '_speaker_theme_hide_post_title' );
	} else {
		update_post_meta( $post_id, '_speaker_theme_hide_post_title', $value );
	}

	// footer widgets
	if ( $value_footer_widgets == '' ) {
		delete_post_meta( $post_id, '_speaker_theme_hide_footer_widgets' );
	} else {
		update_post_meta( $post_id, '_speaker_theme_hide_footer_widgets', $value_footer_widgets );
	}

	// footer bottom
	if ( $value_footer_bottom == '' ) {
		delete_post_meta( $post_id, '_speaker_theme_hide_footer_bottom' );
	} else {
		update_post_meta( $post_id, '_speaker_theme_hide_footer_bottom', $value_footer_bottom );
	}

} add_action( 'save_post', 'speaker_theme_post_elements_meta_box_save' );

/**
 * Custom nav menu - Save
 *
 * @since 1.0
 */
function speaker_theme_custom_nav_menu_meta_box_save( $post_id ) {

	// do not proceed if nonce not set
	if ( ! isset( $_POST['speaker_theme_custom_nav_menu_nonce'] ) ) {
		return $post_id;
	}

	// get nonce value
	$nonce = $_POST['speaker_theme_custom_nav_menu_nonce'];

	// do not proceed if nonce is wrong
	if ( ! wp_verify_nonce( $nonce, 'speaker_theme_custom_nav_menu' ) ) {
		return $post_id;
	}

	// do not proceed if autosave
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return $post_id;
	}

	// do not proceed if user does not have permission
	if ( 'page' == $_POST['post_type'] ) {
		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return $post_id;
		}
	} else {
		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return $post_id;
		}
	}

	/**
	 * Get values
	 */

	// featured images
	$value = '';
	if ( isset( $_POST['_speaker_theme_custom_nav_menu'] ) ) {
		$value = sanitize_text_field( $_POST['_speaker_theme_custom_nav_menu'] );	
	}

	/**
	 * Update
	 */

	// featured image
	if ( $value == '' ) {
		delete_post_meta( $post_id, '_speaker_theme_custom_nav_menu' );
	} else {
		update_post_meta( $post_id, '_speaker_theme_custom_nav_menu', $value );
	}

} add_action( 'save_post', 'speaker_theme_custom_nav_menu_meta_box_save' );