<?php
/**
 * Table of Contents
 *
 * speaker_theme_term_options_scripts ( Enqueue admin scripts and styles )
 * speaker_theme_category_options_add ( Display option for categories )
 * speaker_theme_category_options_save ( Save option for categories )
 * speaker_theme_tag_options_add ( Display option for tags )
 * speaker_theme_tags_options_save ( Save option for tags )
 */

/**
 * Enqueue admin scripts and styles
 *
 * @since 1.0
 */
function speaker_theme_term_options_scripts( $hook ) {

	// if not on term edit
	if ( 'term.php' != $hook ) {
		return;
	}

	// the media library
	wp_enqueue_media();

	// custom scripts
	wp_register_script( 'speaker-theme-term-options-scripts', get_template_directory_uri() . '/js/term-options.js', array( 'jquery' ) );
	wp_localize_script( 'speaker-theme-term-options-scripts', 'meta_image',
		array(
			'title' => __( 'Set custom header image', 'speaker-theme' ),
			'button' => __( 'Use this image', 'speaker-theme' ),
		)
	);
	wp_enqueue_script( 'speaker-theme-term-options-scripts' );

	// custom CSS
	wp_enqueue_style( 'speaker-theme-term-options-style', get_template_directory_uri() . '/css/term-options.css' );

} add_action( 'admin_enqueue_scripts', 'speaker_theme_term_options_scripts' );

/**
 * Display option for categories
 *
 * @since 1.0
 */
function speaker_theme_category_options_add( $tag ) {

	$speaker_theme_category_meta = get_option( 'speaker_theme_category_meta' );
	$value = '';
	if ( isset( $speaker_theme_category_meta[ $tag->term_id ] ) ) { $value = esc_attr( $speaker_theme_category_meta[ $tag->term_id ]['speaker_theme_category_img'] ); }
	?>

	<tr class="form-field">
		<th scope="row" valign="top"><label for="speaker-theme-category-img"><?php esc_html_e( 'Custom Header Image', 'speaker-theme'); ?></label></th>
		<td>
			<div class="speaker-theme-term-options-upload <?php if ( $value ) echo 'speaker-theme-term-options-upload-active'; ?>">
		
				<div class="speaker-theme-term-options-upload-thumbnail">
					<?php 
						if ( $value ) {
							$image = wp_get_attachment_image_src( $value, 'medium' );
							echo '<img style="max-width: 100%;" src="' . $image[0] . '" />';					
						} 
					?>
				</div><!-- .speaker-theme-term-options-upload-thumbnail -->

				<p class="speaker-theme-term-options-upload-note"><?php esc_html_e( 'Click the image to edit or update', 'speaker-theme' ); ?></p>

				<a href="#" class="speaker-theme-term-options-upload-button"><?php esc_html_e( 'Set custom header image', 'speaker-theme' ); ?></a>
				<a href="#" class="speaker-theme-term-options-upload-clear"><?php esc_html_e( 'Remove custom header image', 'speaker-theme' ); ?></a>

				<input type="hidden" class="speaker-theme-term-options-upload-id" id="speaker-theme-category-img" name="speaker_theme_category_meta[<?php echo esc_attr( $tag->term_id ); ?>][speaker_theme_category_img]" value="<?php echo esc_attr( $value ); ?>" />

			</div><!-- .speaker-theme-term-options-upload -->
		</td>
	</tr>
	
	<?php

} add_action( 'edit_category_form_fields', 'speaker_theme_category_options_add' );

/**
 * Save option for categories
 *
 * @since 1.0
 */
function speaker_theme_category_options_save() {

	if ( isset( $_POST['speaker_theme_category_meta'] ) ) {

		if ( get_option('speaker_theme_category_meta' ) ) {
			$current_options = get_option( 'speaker_theme_category_meta' );
		} else {
			$current_options = array();
		}

		$post_info = $_POST['speaker_theme_category_meta'];
		if ( is_array( $post_info ) ) {
			foreach( $post_info as $key => $value ) {
				$current_options[$key] = $value;
			}
		}

		update_option('speaker_theme_category_meta', $current_options);
		
	}

} add_action( 'edit_category', 'speaker_theme_category_options_save' );

/**
 * Display option for tags
 *
 * @since 1.0
 */
function speaker_theme_tag_options_add( $tag ) {

	$speaker_theme_tag_meta = get_option( 'speaker_theme_tag_meta' );
	$value = '';
	if ( isset( $speaker_theme_tag_meta[ $tag->term_id ] ) ) { $value = esc_attr( $speaker_theme_tag_meta[ $tag->term_id ]['speaker_theme_tag_img'] ); }

	?>

	<tr class="form-field">
		<th scope="row" valign="top"><label for="speaker-theme-tag-img"><?php esc_html_e( 'Custom Header Image', 'speaker-theme'); ?></label></th>
		<td>
			<div class="speaker-theme-term-options-upload <?php if ( $value ) echo 'speaker-theme-term-options-upload-active'; ?>">
		
				<div class="speaker-theme-term-options-upload-thumbnail">
					<?php 
						if ( $value ) {
							$image = wp_get_attachment_image_src( $value, 'medium' );
							echo '<img style="max-width: 100%;" src="' . $image[0] . '" />';					
						} 
					?>
				</div><!-- .speaker-theme-term-options-upload-thumbnail -->

				<p class="speaker-theme-term-options-upload-note"><?php esc_html_e( 'Click the image to edit or update', 'speaker-theme' ); ?></p>

				<a href="#" class="speaker-theme-term-options-upload-button"><?php esc_html_e( 'Set custom header image', 'speaker-theme' ); ?></a>
				<a href="#" class="speaker-theme-term-options-upload-clear"><?php esc_html_e( 'Remove custom header image', 'speaker-theme' ); ?></a>

				<input type="hidden" class="speaker-theme-term-options-upload-id" id="speaker-theme-tag-img" name="speaker_theme_tag_meta[<?php echo esc_attr( $tag->term_id ); ?>][speaker_theme_tag_img]" value="<?php echo esc_attr( $value ); ?>" />

			</div><!-- .speaker-theme-term-options-upload -->
		</td>
	</tr>
	
	<?php

} add_action( 'edit_tag_form_fields', 'speaker_theme_tag_options_add' );

/**
 * Save option for tags
 *
 * @since 1.0
 */
function speaker_theme_tags_options_save() {

	if ( isset( $_POST['speaker_theme_tag_meta'] ) ) {

		if ( get_option('speaker_theme_tag_meta' ) ) {
			$current_options = get_option( 'speaker_theme_tag_meta' );
		} else {
			$current_options = array();
		}

		$post_info = $_POST['speaker_theme_tag_meta'];
		if ( is_array( $post_info ) ) {
			foreach( $post_info as $key => $value ) {
				$current_options[$key] = $value;
			}
		}

		update_option('speaker_theme_tag_meta', $current_options);
		
	}

} add_action( 'edit_post_tag', 'speaker_theme_tags_options_save' );